/**
 * @class APIBuilder.Metadata
 * Collection of metadata objects used for field validation of the connector's
 * configuration object.
 *
 * The {@link APIBuilder.Connector#fetchMetadata} method should return an object with its `fields`
 * property set to an array of metadata objects used to validate the connector's configuration.
 *
 *     APIBuilder.Connector.extend({
 * 	       fetchMetadata: function (cb) {
 * 	           cb(null, {
 * 	               fields: [
 *                     APIBuilder.Metadata.Text({
 * 	                       name: 'username',
 *                         description: 'Username account',
 *                         default: 'admin',
 *                         required: true
 *                     }),
 *                     // more metadata objects...
 *                 ]
 *             });
 *         },
 *         // more connector methods...
 *     });
 */

/**
 * @class APIBuilderMetadataObject
 * Basic metadata object.
 * @pseudo
 */
/**
 * @property {Any} default
 * Default value for the field if undefined.
 * Default is an empty string or zero depending on the metadata.
 */
/**
 * @property {String} description
 * Human-readable description of the field.
 */
/**
 * @property {String} name
 * Field name.
 */
/**
 * @property {Boolean} required
 * Set to `true` if the field is required. Default is false.
 */
/**
 * @property {RegExp} validator
 * Regular expression used to validate the field value.
 */

/**
 * @class APIBuilder.Metadata.Checkbox
 * @extends APIBuilderMetadataObject
 * Metadata object used to evaluate a checkbox value. The validator property is not implemented.
 */
/**
 * @constructor
 * Creates a new metadata object.
 * @param {Object} params Set any Metadata properties on the object.
 */
/**
 * @property {Boolean} selected
 * Indicates if the checkbox is selected or not. Default is false.
 */

/**
 * @class APIBuilder.Metadata.NumField
 * @extends APIBuilderMetadataObject
 * Metadata object used to evaluate a floating point value. By default, the validator property
 * is set to validate floating point value.
 */
/**
 * @constructor
 * Creates a new metadata object.
 * @param {Object} params Set any Metadata properties on the object.
 */

/**
 * @class APIBuilder.Metadata.Text
 * @extends APIBuilderMetadataObject
 * Metadata object used to evaluate a text value. The validator property is not implemented.
 */
/**
 * @constructor
 * Creates a new metadata object.
 * @param {Object} params Set any Metadata properties on the object.
 */
