
/**
 * this is a auth strategy which will simply look for a value
 * in the header only and if the header value matches what we
 * expect, we let the request proceed, otherwise, we deny it
 */
function HeaderValueAuthStrategy(server) {
	this.config = server.config;
}

HeaderValueAuthStrategy.prototype.validateRequest = function (req) {
	var key = req.headers.apikey;
	return (key === this.config.apikey);
};

HeaderValueAuthStrategy.prototype.getSwaggerSecurity = function () {
	return {
		securityDefinitions: {
			apikey: {
				type: 'apiKey',
				name: 'apikey',
				in: 'header',
				description: 'Require authorized access to API'
			}
		},
		security: [{
			apikey: []
		}]
	};
};

HeaderValueAuthStrategy.prototype.applyCredentialsForTest = function (opts) {
	opts.headers.APIKey = this.config.apikey;
};

module.exports = HeaderValueAuthStrategy;

