/**
 * Calls the `getMiddleware` function on all the pluggable middlewares.
 * @param {APIBuilder} apibuilder  - The API Builder instance.
 * @returns <Promise>
 */
async function startMiddlewares(apibuilder) {
	const middlewareManager = apibuilder._internal.getMiddlewareManager();

	const { apibuilderPlugins: plugins } = apibuilder;
	for (const pluginName in plugins) {
		const { middlewares } = plugins[pluginName].components;
		for (const type in middlewares) {
			const getMiddleware = middlewares[type];
			middlewareManager.add(getMiddleware);
		}
	}

	await middlewareManager.init(apibuilder.app, {
		config: apibuilder.config,
		logger: apibuilder.logger
	});
}

module.exports = startMiddlewares;
