const util = require('util');

/**
 * Stops all registered dataconnectors.
 */
async function stopConnectors() {
	this.logger.trace('stopping connectors');
	const connectors = this.getConnectors();
	for (const [ name, connector ] of Object.entries(connectors)) {
		if (connector.disconnect) {
			this.logger.trace(`stopping connector ${name}`);
			const disconnectAsync = util.promisify(connector.disconnect.bind(connector));
			try {
				await disconnectAsync();
				this.logger.trace(`stopped connector ${name}`);
			} catch (ex) {
				const connectorName = `connector/${connector.name}`;
				this.logger.error(`Error disconnecting ${connectorName}.`, ex);
			}
		}
		delete connectors[name];
	}
}

module.exports = stopConnectors;
