
/**
 * Verifies that all loaded schemas are valid.
 * Most validation is done when they are loaded, but this calls .get which
 * will throw errors if schemas have issues such as unresolvable refs.
 * Can be simplified when we remove warnOnly and
 * exitOnSwaggerSchemaValidationError flag
 * @param {object} schemas - axway-schema instance
 * @param {object} options - validation options.
 * @param {boolean} options.warnOnly - will warn and not throw any exception.
 * @param {boolean} options.logger - the logger
 */
function validateSchema(schemas, { warnOnly, logger }) {
	logger.trace('Validating loaded schema');
	if (!warnOnly) {
		// Just throw if there's an issue to avoid a redundant try/catch/throw
		return schemas.get();
	}

	try {
		schemas.get();
	} catch (err) {
		logger.warn(err);
	}
}

module.exports = validateSchema;
